pub struct FileSource {
pub name: EntryName,
pub source: PathBuf,
}Fields
name: EntryNamesource: PathBufTrait Implementations
Sourceimpl Clone for FileSource
impl Clone for FileSource
Sourcefn clone(&self) -> FileSource
fn clone(&self) -> FileSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<FileSource> for FileSource
impl From<FileSource> for FileSource
Sourcefn from(x: FileSource) -> Self
fn from(x: FileSource) -> Self
Converts to this type from the input type.
Sourceimpl PyClass for FileSource
impl PyClass for FileSource
Sourceimpl PyClassImpl for FileSource
impl PyClassImpl for FileSource
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourcetype Layout = PyCell<FileSource>
type Layout = PyCell<FileSource>
Layout
Sourcetype ThreadChecker = ThreadCheckerStub<FileSource>
type ThreadChecker = ThreadCheckerStub<FileSource>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature<FileSource> for PyClassImplCollector<FileSource>
impl PyClassNewTextSignature<FileSource> for PyClassImplCollector<FileSource>
fn new_text_signature(self) -> Option<&'static str>
Sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a FileSource
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a FileSource
Sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut FileSource
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut FileSource
Sourceimpl PyMethods<FileSource> for PyClassImplCollector<FileSource>
impl PyMethods<FileSource> for PyClassImplCollector<FileSource>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for FileSource
impl PyTypeInfo for FileSource
Sourcetype AsRefTarget = PyCell<FileSource>
type AsRefTarget = PyCell<FileSource>
Utility type to make Py::as_ref work.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
Returns the safe abstraction over the type object.
Sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
Checks if
object is an instance of this type or a subclass of this type.Sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
Checks if
object is an instance of this type.Sourceimpl TryFrom<FileSource> for FileSource
impl TryFrom<FileSource> for FileSource
Sourcetype Error = MedusaNameFormatError
type Error = MedusaNameFormatError
The type returned in the event of a conversion error.